@@ -486,8 +486,9 @@ basicConstraints = CA:false""" % {'certdir': os.path.join(self.testdir,
         return self.run_and_collect([self.pycmd, exe], env)
 
     def run_and_collect(self, cmd, env):
-        p = subprocess.Popen(cmd, env=env,
-                             stdout=subprocess.PIPE, stderr=self.stderr)
+        p = subprocess.Popen(
+            cmd, env=env, universal_newlines=True,
+            stdout=subprocess.PIPE, stderr=self.stderr)
         results = []
         for line in p.stdout:
             line = line[:-1]  # Strip newline
