@@ -295,7 +295,7 @@ if __name__ == '__main__':
             'providers/openidc/admin/client/%s' % reg_resp['client_id'],
             {'Client Name': 'Test suite client updated'})
 
-    with TC.case('Retrieving toke info'):
+    with TC.case('Retrieving token info'):
         # Testing token without client auth
         r = requests.post('https://127.0.0.10:45080/idp1/openidc/TokenInfo',
                           data={'token': new_token['access_token']})
